// ContentRecommendation.ts

import {
  getRecommendation,
  RecommendationOptions,
} from "../api/getRecommendation";

// Init drupal
declare const Drupal: any;

export class ContentRecommendation {
  private static attached: boolean = false;

  public static attach(context: HTMLElement): void {
    if (!ContentRecommendation.attached) {
      ContentRecommendation.attached = true;

      const populateRecommendation = async (entity: any): Promise<void> => {
        // Get the UID
        const uid = entity?.data?.user?._uid;

        // Get all Block Elements
        const recContainers = document.querySelectorAll(
          '[id*="rec-container-"]'
        );
        for (const element of Array.from(recContainers)) {
          const recommendationConfig = JSON.parse(
            atob(element.getAttribute("data-rec-config") || "")
          );

          const accountId = recommendationConfig?.account_id;
          const target = recommendationConfig?.element;
          const maxItems = recommendationConfig?.number_of_recommendations;

          // if no account id, skip
          if (!accountId) {
            console.warn("No account ID provided for recommendations.");
            return;
          }

          if (!uid) {
            console.warn("No visitor ID provided for recommendations.");
            return;
          }

          // Validate options
          const options = {
            element: recommendationConfig?.element,
            type: recommendationConfig?.recommendation_type,
            collection: recommendationConfig?.content_collection_id,
            engine: recommendationConfig?.interest_engine_id,
            segment: recommendationConfig?.segment_id,
            url: recommendationConfig?.url,
            noShuffle: recommendationConfig?.dont_shuffle_results,
            includeViewed: recommendationConfig?.include_viewed_content,
            maxItems: recommendationConfig?.number_of_recommendations,
          } as RecommendationOptions;

          try {
            const data = await getRecommendation(accountId, uid, options);
            const recContainer = document.querySelector(`#${target}`);

            if (recContainer) {
              recContainer.innerHTML = "";

              let count = 0;

              // handle invalid response due to no recommendation or error
              if (!data || data.length === 0) {
                recContainer.innerHTML = "No recommendations available.";
                return;
              }

              data.forEach((rec: any) => {
                if (count >= maxItems) {
                  return;
                }

                const recItem = document.createElement("div");

                recItem.classList.add(
                  "flex-container",
                  "flex-column",
                  "justify-start",
                  "align-stretch",
                  "flex-1",
                  "gap-small",
                  "rec-item"
                );

                if (
                  (rec?.primaryimageurl !== undefined &&
                    rec?.primaryimageurl !== "") ||
                  (rec?.imageurls?.length > 0 && rec?.imageurls?.[0] !== "")
                ) {
                  const img = document.createElement("img");
                  img.classList.add("rec-img");
                  img.alt = `Image of ${rec.title}`;
                  img.src = rec.primaryimageurl || rec.imageurls[0];
                  recItem.appendChild(img);
                } else {
                  return;
                }

                const recTitle = document.createElement("div");
                recTitle.classList.add("rec-title");
                recItem.appendChild(recTitle);

                const titleLink = document.createElement("a");
                const protocol = window.location.protocol;
                titleLink.href = `${protocol}//${rec.url}`;
                titleLink.innerHTML = `<strong>${rec.title}</strong>`;
                recTitle.appendChild(titleLink);

                if (rec.description) {
                  const description = document.createElement("p");
                  description.classList.add("rec-description");
                  description.textContent = rec.description;
                  recItem.appendChild(description);
                }

                recContainer.appendChild(recItem);

                count++;
              });
            }
          } catch (error) {
            console.error("Error fetching recommendations:", error);
          }
        }
      };

      (window as any).jstag.call("entityReady", populateRecommendation);
    }
  }
}

// Define a Drupal behavior using the class above
Drupal.behaviors.contentRecommendation = {
  attach: ContentRecommendation.attach,
};
